@@ -941,11 +941,19 @@ get_length_of_longest_title()
 {
 	gint max_length = 0;
 	AppData *app_data = get_app_data();
+	GtkTreeIter iter;
+	GtkTreeModel *model = GTK_TREE_MODEL(app_data->note_store);
+	gboolean valid = gtk_tree_model_get_iter_first(model, &iter);
 	
-	GList *notes = app_data->search_list;
-	while (notes != NULL) {
-		max_length = max(g_utf8_strlen(((Note*)notes->data)->title, -1), max_length);
-		notes = notes->next;
+	/*GList *notes = app_data->search_list;
+	while (notes != NULL) {*/
+	while (valid) {
+		Note *note;
+		gtk_tree_model_get(model, &iter, NOTE_COLUMN, &note, -1);
+		/*max_length = max(g_utf8_strlen(((Note*)notes->data)->title, -1), max_length);*/
+		max_length = max(g_utf8_strlen(note->title, -1), max_length);
+		/*notes = notes->next;*/
+		valid = gtk_tree_model_iter_next(model, &iter);
 	}
 	
 	return max_length;
@@ -980,10 +988,15 @@ GSList* find_titles(gchar *haystack) {
 	gchar *u_haystack = g_utf8_casefold(haystack, -1);
 	gulong micro;
 	
-	GList *notes = app_data->search_list;
-	while (notes != NULL) {
+	/*GList *notes = app_data->search_list;
+	while (notes != NULL) {*/
+	GtkTreeIter iter;
+	GtkTreeModel *model = GTK_TREE_MODEL(app_data->note_store);
+	gboolean valid = gtk_tree_model_get_iter_first(model, &iter);
+	while (valid) {
 		gchar *u_needle;
-		note = (Note*)notes->data;
+		/*note = (Note*)notes->data;*/
+		gtk_tree_model_get(model, &iter, NOTE_COLUMN, &note, -1);
 		
 		u_needle = g_utf8_casefold(note->title, -1);
 		
@@ -998,13 +1011,14 @@ GSList* find_titles(gchar *haystack) {
 			found = found + strlen(u_needle);
 		}
 		g_free(u_needle);
-		notes = notes->next;
+		/*notes = notes->next;*/
+		valid = gtk_tree_model_iter_next(model, &iter);
 	}
 	
 	g_timer_stop(search_timer);
 	
 	g_timer_elapsed(search_timer, &micro);
-	g_printerr("Search took %lu microseconds \n", micro);
+	/*g_printerr("Search took %lu microseconds \n", micro);*/
 	
 	g_free(u_haystack);
 	
@@ -1152,7 +1166,7 @@ on_text_buffer_insert_text					(GtkTextBuffer *buffer,
 	
 	g_timer_stop(timer);
 	g_timer_elapsed(timer, &micro);
-	g_printerr("Complete insert: %lu ms \n", micro);
+	g_printerr("%lu\n", micro);
 }
 
 void
